@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 # lesspipe.sh, a preprocessor for less
-lesspipe_version=2.14
+lesspipe_version=2.15
 # Author: Wolfgang Friebel (wp.friebel AT gmail.com)
 
 has_cmd () {
@@ -418,13 +418,7 @@ analyze_args () {
 	cmdtree=$(ps -T -oargs= 2>/dev/null)
 	while read -r line; do
 		arg1=${line%% *}; arg1=${arg1##*/}
-		case $arg1 in
-			man|git|perldoc)
-	# if lesspipe is called in pipes, return immediately for some use cases
-				exit 0 ;;
-			less)
-				lessarg=$line ;;
-		esac
+		[[ $arg1 == less ]] && lessarg=$line
 	done <<< "$cmdtree"
 	# return if we want to watch growing files
 	[[ $lessarg == *less\ *\ +F\ * || $lessarg == *less\ *\ : ]] && exit 0
@@ -457,23 +451,32 @@ has_colorizer () {
 	[[ -n $3 ]] && lang=$3 || lang=$2
 	case $prog in
 		bat|batcat)
+			batconfig=$($prog --config-file)
 			[[ -n $lang ]] && $prog --list-languages|sed 's/.*:/,/;s/$/,/'|grep -i ",$lang," > /dev/null && opt=(-l "$lang")
-			[[ -n $LESSCOLORIZER && $LESSCOLORIZER = *\ *--style=* ]] && style="${LESSCOLORIZER/* --style=/}"
+			opt2=${LESSCOLORIZER##*--}
+			[[ $opt2 == style=* ]] && style=${opt2##*=}
+			[[ $opt2 == theme=* ]] && theme=${opt2##*=}
+			opt2=$(echo "$LESSCOLORIZER"|tr -s ' ')
+			opt2=${opt2%[ ]--*}
+			opt2=${opt2##*--}
+			[[ $opt2 == style=* ]] && style=${opt2##*=}
+			[[ $opt2 == theme=* ]] && theme=${opt2##*=}
+			[[ -n $theme ]] && theme=$(echo "${theme##*=}"|tr -d '/"\047\134/')
 			[[ -z $style ]] && style=$BAT_STYLE
-			[[ -n $LESSCOLORIZER && $LESSCOLORIZER = *\ *--theme=* ]] && theme="${LESSCOLORIZER/* --theme=/}"
 			[[ -z $theme ]] && theme=$BAT_THEME
-			if [[ -r "$HOME/.config/bat/config" ]]; then
+			if [[ -r "$batconfig" ]]; then
 				if [[ -z $style ]]; then
-					grep -q -e '^--style' "$HOME/.config/bat/config" || style=plain
+					grep -q -e '^--style' "$batconfig" || style=plain
 				fi
 				if [[ -z $theme ]]; then
-					grep -q -e '^--theme' "$HOME/.config/bat/config" || theme=ansi
+					grep -q -e '^--theme' "$batconfig" || theme=ansi
 				fi
 			else
 				[[ -z $style ]] && style=plain
 				[[ -z $theme ]] && theme=ansi
 			fi
-			opt+=(--style="${style%% *}" --theme="${theme%%[|&;<>]*}")
+			style="${style%% *}" theme="${theme%%[|&;<>]*}"
+			opt+=(${style:+--style="$style"} ${theme:+--theme="$theme"})
 			opt+=("$COLOR" --paging=never "$1") ;;
 		pygmentize)
 			pygmentize -l "$lang" /dev/null &>/dev/null && opt=(-l "$lang") || opt=(-g)
@@ -492,7 +495,12 @@ has_colorizer () {
 			[[ -n "$3" ]] && opt=(-l "$3" "$1") ;;
 		nvimpager)
 			opt=(-c "$1")
-			[[ -n "$3" ]] && opt=(-c "$1" -c "set filetype=$3") ;;
+			if [[ -n "$3" ]]; then
+				ft=${3##*/}
+				ft=${ft##*.}
+				opt=(-c "$1" --cmd "set filetype=$ft")
+			fi
+			;;
 		*)
 			return ;;
 	esac
@@ -581,11 +589,11 @@ isfinal () {
 			declare macro=andoc
 			[[ "$fext" == me ]] && macro=e
 			[[ "$fext" == ms ]] && macro=s
-# groff 1.23 fails test #74 as it produces escape codes: disable with -a
-#			{ has_cmd groff && cmd=(groff -s -p -t -e -Tutf8 -m "$macro" "$1"); } ||
-			{ has_cmd groff && cmd=(groff -a -s -p -t -e -Tutf8 -m "$macro" "$1"); } ||
 			{ has_cmd mandoc && cmd=(nodash mandoc "$1"); } ||
-			{ has_cmd man && cmd=(nodash man "$1"); } ;;
+			{ has_cmd man && cmd=(man -l "$1"); } ||
+# groff 1.23 fails test #74 as it produces escape codes: disable with -a
+#			{ [[ $COLOR == *always ]] && has_cmd groff && cmd=(groff -s -p -t -e -Tutf8 -m "$macro" "$1"); } ;;
+			{ [[ $COLOR == *always ]] && has_cmd groff && cmd=(groff -a -s -p -t -e -Tutf8 -m "$macro" "$1"); } ;;
 		rtf)
 			{ has_cmd unrtf && cmd=(istemp "unrtf --text" "$1"); } ||
 			{ has_cmd libreoffice && cmd=(isoffice2 "$1"); } ;;
@@ -596,7 +604,7 @@ isfinal () {
 		pod)
 			[[ -z $file2 ]] &&
 			{ { has_cmd pod2text && cmd=(pod2text "$1"); } ||
-			{ has_cmd perldoc && cmd=(istemp perldoc "$1"); }; } ;;
+			{ has_cmd perldoc && cmd=(istemp "perldoc -T" "$1"); }; } ;;
 		hdf|hdf5)
 			{ has_cmd h5dump && cmd=(istemp h5dump "$1"); } ||
 			{ has_cmd ncdump && cmd=(istemp ncdump "$1"); } ;;
@@ -605,7 +613,7 @@ isfinal () {
 		djvu)
 			has_cmd djvutxt && cmd=(djvutxt "$1") ;;
 		x509|crl)
-			has_cmd openssl && cmd=(istemp "openssl $x -hash -text -noout -in" "$1") ;;
+			has_cmd openssl && cmd=(istemp "openssl storeutl -text -noout" "$1") ;;
 		csr)
 			has_cmd openssl && cmd=(istemp "openssl req -text -noout -in" "$1") ;;
 		pgp)
@@ -673,10 +681,10 @@ isarchive () {
 		case $prog in
 			tar|bsdtar)
 				[[ "$2" =~ ^[a-z_-]*:.* ]] && echo "$2: remote operation tar host:file not allowed" && return
-				if [[ "$3" =~ --* ]]; then
-					$prog Oxf "$2" "--" "$3" 2>/dev/null
+				if [[ "$3" =~ .*/$ ]]; then
+					$prog Otvf "$2" -- "$3"
 				else
-					$prog Oxf "$2" "$3" 2>/dev/null
+					$prog Oxf "$2" -- "$3" 2>/dev/null
 				fi
 				;;
 			rar|unrar)
@@ -749,7 +757,7 @@ isimage () {
 		fi
 		istemp "unsquashfs -d . -llc $offset" "$2"
 	else
-		istemp "unsquashfs -cat $offset"  "$2" "$3"
+		istemp "unsquashfs -cat $offset" "$2" "$3"
 	fi
 }
 
@@ -857,13 +865,15 @@ handle_w3m () {
 
 ishtml () {
 	[[ $1 == - ]] && arg1=-stdin || arg1="$1"
+	htmlopt=--unicode-snob
+	has_cmd html2text && echo ""|html2text -utf8 2>/dev/null && htmlopt=-utf8
 	# 3 lines following can easily be reshuffled according to the preferred tool
 	has_cmd elinks && nodash "elinks -dump -force-html" "$1" && return ||
 	has_cmd w3m && handle_w3m "$1" && return ||
 	has_cmd lynx && lynx -force_html -dump "$arg1" && return ||
-	# different versions of html2text existing, therefore no encoding handling
+	# different versions of html2text existingi, force unicode
 	[[ "$1" == https://* ]] && return ||
-	has_cmd html2text && nodash html2text "$1"
+	has_cmd html2text && nodash html2text "$htmlopt" "$1"
 }
 
 # the main program
